@@ -16,6 +16,7 @@
  */
 
 #include <libgnomevfsmm/private.h>
+#include <glibmm/error.h>
 
 #include <libgnomevfsmm/enums.h>
 
@@ -25,11 +26,22 @@ namespace Gnome
 namespace Vfs
 {
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void handle_result(GnomeVFSResult result) throw(Gnome::Vfs::exception)
 {
   if(result != GNOME_VFS_OK)
     throw(Gnome::Vfs::exception(static_cast<Gnome::Vfs::Result>(result)));
 }
+#else
+void handle_result(GnomeVFSResult result, std::auto_ptr<Gnome::Vfs::exception>& error)
+{
+  if(result != GNOME_VFS_OK)
+  {
+    std::auto_ptr<Gnome::Vfs::exception> e(new Gnome::Vfs::exception(static_cast<Gnome::Vfs::Result>(result)));
+    error = e;
+  }
+}
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 } // namespace Vfs
 } // namespace Gnome
